@@ -135,8 +135,8 @@
 #define TITRAQ_SEPARATORTOK     " "
 #define TITRAQ_HOMEDIRTOK       "~/"
 #define TITRAQ_FEXTENSION       ".as"
-#define TITRAQ_SAVEFIRST        "The timesheet contains unsaved changes\nDo you want to save the changes or discard them?"
-#define TITRAQ_OVERWRITE        "A file already exists with the chosen name\nDo you want to overwrite it with new data?"
+#define TITRAQ_SAVEFIRST        "The timesheet contains unsaved changes.\nDo you want to save the changes or discard them?"
+#define TITRAQ_OVERWRITE        "A file already exists with the chosen name.\nDo you want to overwrite it with new data?"
 
 // Indexes of table columns
 #define TITRAQ_IDXALLCTRLS     -1
