@@ -51,6 +51,7 @@ Titraqform::Titraqform(QWidget *pParent, const char *kszName, WFlags Flags) :
     // Atenzione! Order is very important in the following sequence.
     // FIXME: Reorganize this procedural mess into self contained objects
     try {
+        int nUnhandled;         // Holds number of unhandled cmd args
         setupPrefs();           // Load general preferences
         setupActions();         // Create and initialize actions
         setupMenubar();         // Create and initialize menu bar
@@ -61,6 +62,9 @@ Titraqform::Titraqform(QWidget *pParent, const char *kszName, WFlags Flags) :
         setupEditlay();         // Create and initialize edit controls
         setupColumns();         // Prepare columns for viewing, sorting
         enableIface(false);     // Start things off in a empty state
+
+        nUnhandled = setupCmdargs(); // Parse the command line, and init file
+        setupInitdata(nUnhandled);   // Possibly open an inital event data file
     }
     catch (Genexcept& Genex) {
         Genex.reportErr();
@@ -84,8 +88,6 @@ Titraqform::Titraqform(QWidget *pParent, const char *kszName, WFlags Flags) :
 //    // Lock down window size
 //    setSizePolicy(QSizePolicy((QSizePolicy::SizeType)0,
 //        (QSizePolicy::SizeType)0, 0, 0, sizePolicy().hasHeightForWidth()));
-
-    m_pStatbar->message(trUtf8("Ready"));   // Signal a ready condition
 }
 
 //
