@@ -246,6 +246,8 @@ private:
     void setupPieces(void);             // Assemble widget pieces
     void setupColumns(void);            // Arrange and configure columns
     void enableIface(bool);             // [En/dis]able most ui pieces
+    int setupCmdargs(void);             // Parse the command line args
+    void setupInitdata(int);            // Opens an inital event data file
 
     // Data processing
     void loadAccounts(QFile &);         // Load accounts from file
