@@ -34,12 +34,10 @@
 
 int main(int argc, char **argv)
 {
-    QApplication App(argc, argv);
+    QApplication App(argc, argv, QApplication::GuiClient);
 
     Titraqform Mainform;            // Main app window
     App.setMainWidget(&Mainform);
     Mainform.show();                // Finally start the show
-    App.connect(&App, SIGNAL(lastWindowClosed()), &App, SLOT(quit()));
-    App.connect(&App, SIGNAL(aboutToQuit()), &Mainform, SLOT(savePrefs()));
     return App.exec();
 }
